import nbformat as nbf, os
from datetime import date
from getpass import getuser


nb = nbf.v4.new_notebook()


def create_fab_notebook(name, path):
    text = [
        f"""\
<img src="./include/img/fabric_logo.png" width="500"/>

# {name}
```
Created: {date.today()}
Last Modified: 
{getuser()}
Clemson University
<username>@clemson.edu
```

<div style="page-break-after: always; visibility: hidden"> 
\pagebreak 
</div>"""
    ]

    code = [
        """\
from fabrictestbed_extensions.fablib.fablib import FablibManager as fablib_manager

try:
    fablib = fablib_manager()
                     
    fablib.show_config()
except Exception as e:
    print(f"Exception: {e}")""",
        """\
# Clean up log directory to avoid large files
import os
for item in os.scandir(os.path.join(os.getcwd(), 'logs')):
    if '.' != item.name[0]:
        os.remove(item.path)""",
    ]

    nb["cells"] = [
        nbf.v4.new_markdown_cell(text[0]),
        nbf.v4.new_code_cell(code[0]),
        nbf.v4.new_code_cell(code[1]),
    ]

    nbf.write(nb, path + f"/{name.lower()}.ipynb")


def update_fab_notebook(path):
    for item in os.scandir(path):
        if ".ipynb" in item.path and ".ipynb_checkpoints" not in item.path:
            itemPath = item.path
    code = """\
# Clean up log directory to avoid large files
import os
for item in os.scandir(os.path.join(os.getcwd(), 'logs')):
    if '.' != item.name[0]:
        os.remove(item.path)"""
    nb = nbf.read(itemPath, as_version=4)
    nb["cells"].insert(2, nbf.v4.new_code_cell(code))

    nbf.write(nb, itemPath)



# -*- coding: utf-8 -*-
from setuptools import setup

package_dir = \
{'': 'src'}

packages = \
['fabproj_manager', 'fabproj_manager.modules']

package_data = \
{'': ['*'], 'fabproj_manager.modules': ['img/*']}

install_requires = \
['click>=8.1.3,<9.0.0', 'nbformat>=5.7.3,<6.0.0']

entry_points = \
{'console_scripts': ['fabproj = fabproj_manager.fabproj:create_project']}

setup_kwargs = {
    'name': 'fabproj-manager',
    'version': '0.1.4',
    'description': '',
    'long_description': '# fabproj-manager\nA CLI to help create new fabric project templates in an effort to standardize experiment structure.\n\n## Usage\n`fabproj -n [--name] <fabric project name> -c [--command] new`\n- Replace <fabric project name> with a desired name\n- `new` is the only supported command for now.\nOnce you run the above command, you should see a new set of folders that serve as a template\nfor your fabric project.',
    'author': 'Devin Lane',
    'author_email': 'silvertenor@icloud.com',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'None',
    'package_dir': package_dir,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.9,<4.0',
}


setup(**setup_kwargs)



# cli.py
import click, os, sys, shutil

dirname = os.path.dirname(__file__)
sys.path.append(dirname)
import modules.ipyCreate as ipyCreate

cwd = os.getcwd()


@click.command()
# @click.argument("command")
@click.option("--add", "-a", is_flag=True, help="Creates a new project")
@click.option(
    "--update", "-u", is_flag=True, help="Update current project (must be in directory)"
)
@click.option(
    "--name",
    "-n",
    default="myProj",
    show_default=True,
    help="Name of your fabric project",
)
@click.option(
    "--local", "-l", is_flag=True, help="Whether project will need local scripts or not"
)
def create_project(add, update, name, local):
    """
    This tool will help you create new fabric project templates, including
    directory structure.
    """
    if add:
        confirmation = input(
            f"Do you want to add a new project in the current directory? (yes/no) "
        )
        if confirmation == "yes":
            rootdir = os.path.join(cwd, name)
            os.makedirs(rootdir)
            os.makedirs(os.path.join(rootdir, "upload"))
            os.makedirs(os.path.join(rootdir, "download"))
            os.makedirs(os.path.join(rootdir, "include/img"))
            os.makedirs(os.path.join(rootdir, "logs"))
            if local:
                os.makedirs(os.path.join(rootdir, "local"))

            shutil.copy(
                os.path.join(dirname, "modules/img/fabric_logo.png"),
                os.path.join(rootdir, "include/img/fabric_logo.png"),
            )
            ipyCreate.create_fab_notebook(name, rootdir)

    # USE SPARINGLY
    elif update:
        rootdir = os.getcwd()
        ipyCreate.update_fab_notebook(rootdir)


if __name__ == "__main__":
    create_project()
